\name{coldmap.old}
\alias{coldmap.old}
\title{Cooler heatmap (deprecated old version)}
\description{Heatmap for large data matrices}
\usage{
coldmap.old( x,
  clust = NULL,
  cclust = NULL,
  rclust = NULL,
  ccenter = TRUE,
  rcenter = FALSE,
  downsampling = NULL,
  col = rg.colors,
  saturation = .666, 
  clab = NULL, 
  labspace=0.01,
  labcol = NULL,
  zw = NULL,
  zc = NULL
  )
}
\arguments{
\item{x}{Data matrix}
\item{clust}{clustering output (of previous call to \code{coldmap.old})}
\item{cclust}{column dendrogram, output of \code{nclust} or \code{hclust}}
\item{rclust}{row dendrogram, output of \code{nclust} or \code{hclust}}
\item{rcenter,ccenter}{Row and column mean centering for the heatmap.}
\item{downsampling}{Downsampling for display, an integer vector \code{c(a,b)}
  means average every non-overlapping block of size a rows and b columns as
  the heatmap to be plotted. The default is \code{a=1} and \code{b}
  is \code{1 + dim(x)[2]\%/\%500}}
\item{col}{colors as described in \link{heat.colors}. This package
  defines \code{rb.colors} (red-white-blue), \code{rg.colors} (red-black-green)
  and \code{bw.colors} (gray levels)}
\item{saturation}{Degree of color saturation. Negative value invert the
  color gradient.}
\item{clab}{Custom labels: if a vector of integers, they are interpreted
as position in the sorted heatmap. If a vectors of strings
will be matched against   \code{dimnames(x)[[2]]}.}
\item{labspace}{Minimum spacing between labels, as a fraction of
  plot. It is not sensitive to fontsize in relation to the size of
  drawing surface, and therefore overlap or
  ``underlap'' may still occur. It needs to be manually tuned to
  a particular media (or even when resizing graphics windows)}
\item{labcol}{colors for labels}
\item{zw}{zoom width: number of items to be shown around the
zoom center}
\item{zc}{zoom center: either an integer of the dendrogram sorted
index, or a string to be matched against the labels}
}
\details{
\code{coldmap.old} shows heatmap of a data matrix, just like \link{heatmap},
but more computationally efficient by using \link{nclust} for clustering,
and \link{dendrolines} to render the dendograms. It also downsamples
the plotted image such that when the number of items exceed the
number of pixels on the screen or printed paper, only the values
of local blocks are rendered into the graphics object.

Item labels are not all shown. Instead, a user-specified list is
matched against the data labels and plotted accordingly. The labels
are automatically shifted to reduce overlap.

To allow multiple invocations without recomputing the clustering,
the dendrograms can be saved, and given as user-supplied dendrograms.
}
\value{
A list of \code{cclust} and \code{rclust}, for column and row
clustering, respectively. (Note that the columns of the matrix
are on the vertical axis of the plot, following the convention
in \link{image}).
}
\examples{
  data(TGIF1) # microarray dataset from Farmer 2005 Oncogene
              # includes precomputed clusters (TGIF1.clust)
              # and some breast cancer genes as custom labels (bcgenes)

  # show the heatmap
  coldmap.old(TGIF1, clust = TGIF1.clust, clab = bcgenes )
  
  # For new data, the clusters were computed as follow
  # (! This will take a few minutes)
  #  TGIF1.clust <- coldmap.old(TGIF1)

  # if the window is too short, make it tall to see the labels,
  # otherwise, the spacing can be increased
  coldmap.old(TGIF1, clust = TGIF1.clust, clab = bcgenes, labspace = 0.02 )
  
  # show with 50 random labels
  coldmap.old(TGIF1, clust = TGIF1.clust, clab = sample(dimnames(TGIF1)[[2]],50))
  # repeated call to the above gives different labels
  
  # zoom into a window of size 1000, centered around ESR1
  coldmap.old(TGIF1, clust = TGIF1.clust, clab = bcgenes, zw = 2000, zc = "ESR1")

  
}
